<?php

namespace EventPortal\Domain\Agenda;

use EventPortal\Domain\Agenda\DataObject\Agenda as AgendaObject;
use EventPortal\Domain\Agenda\DataObject\Session;
use EventPortal\Domain\Agenda\Models\Agenda;
use EventPortal\Domain\Agenda\Models\Pathway;
use EventPortal\Domain\Delegate\Models\Delegate;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Event\Models\EventDelegate;

class Agendas
{
    public function forEvent(Event $event): array
    {
        return Agenda::forEvent($event)
            ->with([
                'pathways.sessions.eventVenue',
                'pathways.sessions.eventSpeakers',
            ])
            ->orderBy('date')
            ->get()
            ->mapInto(AgendaObject::class)
            ->toArray();
    }

    public function forDelegate(Delegate $delegate, Event $event): array
    {
        $eventDelegate = EventDelegate::forEventAndDelegate($event, $delegate)->first();

        $pathways = Pathway::forEventDelegate($eventDelegate);

        return $pathways->get()->map(static function (Pathway $pathway) {
            $sessions = $pathway
                ->sessions()
                ->orderBy('starting_at')
                ->get()
                ->mapInto(Session::class)
                ->toArray();

            $date = $pathway->agenda->date;
            return [
                'title' => $date->format('jS F'),
                'active' => $date->isSameDay(now()),
                'data' => $sessions,
            ];
        })->toArray();
    }
}
