<?php

namespace EventPortal\Domain\Agenda\DataObject;

use EventPortal\Domain\Agenda\Models\Session as SessionModel;
use Illuminate\Contracts\Support\Arrayable;

class Session implements Arrayable
{
    public function __construct(SessionModel $session)
    {
        $this->name = $session->name;
        $this->description = $session->description;
        $this->startingAt = $session->starting_at->format('H:i');
        $this->duration = $session->readableDuringInMinutes;
        $this->location = $session->location;
        $this->speakers = $session->eventSpeakers->pluck('speaker.name')->toArray();
        $this->venue = $this->getVenueName($session);
    }

    public function toArray(): array
    {
        return [
            'name' => $this->name,
            'description' => $this->description,
            'startingAt' => $this->startingAt,
            'duration' => $this->duration,
            'location' => $this->location,
            'speakers' => $this->speakers,
            'venue' => $this->venue,
        ];
    }

    private function getVenueName(SessionModel $session): ?string
    {
        $eventVenue = $session->eventVenue;
        if ($eventVenue === null) {
            return null;
        }

        return $eventVenue->venue->name;
    }
}
