<?php

namespace EventPortal\Domain\Agenda\Models;

use EventPortal\Domain\Event\Models\EventDelegate;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\BelongsToMany;
use Illuminate\Database\Eloquent\Relations\HasMany;

class Pathway extends Model
{
    const KEY = 'pathway';

    protected $with = ['agenda'];

    /** @var array */
    protected $guarded = [];

    public static function createForAgenda(Agenda $agenda, string $name, string $description): Pathway
    {
        return Pathway::create([
            'agenda_id' => $agenda ->id,
            'name' => $name,
            'description' => $description,
        ]);
    }

    public function sessions(): HasMany
    {
        return $this->hasMany(Session::class);
    }

    public function agenda(): BelongsTo
    {
        return $this->belongsTo(Agenda::class);
    }

    public function eventDelegates(): BelongsToMany
    {
        return $this->belongsToMany(EventDelegate::class, 'delegate_event_pathway', 'pathway_id', 'delegate_event_id');
    }

    public function scopeForEventDelegate(Builder $query, EventDelegate $eventDelegate): Builder
    {
        return $query->whereHas('eventDelegates', static function (Builder $query) use ($eventDelegate): Builder {
            return $query->where('delegate_event_id', $eventDelegate->id);
        });
    }
}
