<?php

namespace EventPortal\Tests\Feature\Delegate\Event;

use Carbon\Carbon;
use EventPortal\Domain\Delegate\Models\Delegate;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Tests\Support\Factories\AgendaFactory;
use EventPortal\Tests\Support\Factories\PathwayFactory;
use EventPortal\Tests\Support\Factories\SessionFactory;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;
use Spatie\Snapshots\MatchesSnapshots;

class AgendaIndexTest extends TestCase
{
    use RefreshDatabase, MatchesSnapshots;

    /** @test */
    public function view_agenda_page()
    {
        Carbon::setTestNow(Carbon::parse('21 October 2020'));

        $delegate = factory(Delegate::class)->state('snapshot')->create();
        $event = factory(Event::class)->state('snapshot')->create();
        $event->delegates()->attach($delegate, ['status' => 'invited']);

        AgendaFactory::make(now(), $event)
            ->createPathway('Default pathway', static function (PathwayFactory $pathwayFactory) use ($delegate): void {
                $pathwayFactory->addDelegate($delegate);
                $pathwayFactory->createSession(
                    [
                        'starting_at' => now(),
                        'ending_at' => now()->addHour(),
                        'name' => 'Session 1',
                        'description' => 'Description for session 1',
                        'location' => 'Studio 1',
                    ],
                    static function (SessionFactory $sessionFactory): void {
                        $sessionFactory->createVenue([
                            'name' => 'Venue one',
                        ]);

                        $sessionFactory->createSpeakerAndUser([], [
                            'first_name' => 'Speaker',
                            'last_name' => 'One',
                        ]);
                    }
                );
            });

        $this->assertMatchesJsonSnapshot(
            $this->actingAs($delegate->user)->get(route('agenda.index', $event))->props()
        );
    }
}
