<?php

namespace EventPortal\Tests\Support\Factories;

use EventPortal\Domain\Agenda\Models\Session;
use EventPortal\Domain\Speaker\Models\Speaker;
use EventPortal\Domain\User\Models\User;
use EventPortal\Domain\Venue\Models\Venue;

class SessionFactory
{
    /**
     * @var Session
     */
    private $session;

    public function __construct(Session $session)
    {
        $this->session = $session;
    }

    public function createSpeakerAndUser(array $speakerData = [], array $userData = []): Speaker
    {
        $data = array_merge(
            $speakerData,
            [
                'user_id' => factory(User::class)->create($userData)->id,
            ],
        );

        $speaker = factory(Speaker::class)->create($data);

        $this->session->eventSpeakers()->create([
            'speaker_id' => $speaker->id,
            'event_id' => $this->session->pathway->agenda->event->id,
        ]);

        return $speaker;
    }

    public function createVenue(array $data = []): Venue
    {
        $venue = factory(Venue::class)->create($data);

        $eventVenue = $this->session->eventVenue()->create([
            'venue_id' => $venue->id,
            'event_id' => $this->session->pathway->agenda->event->id,
        ]);
        $this->session->eventVenue()->associate($eventVenue);
        $this->session->save();


        return $venue;
    }
}
